Struct openssl::sign::RsaPssSaltlen [−][src]
pub struct RsaPssSaltlen(_);Expand description
Salt lengths that must be used with set_rsa_pss_saltlen.
Implementations
Sets the salt length to the given value.
The salt length is set to the digest length.
Corresponds to the special value -1.
The salt length is set to the maximum permissible value.
Corresponds to the special value -2.