Struct openssl::sign::Verifier [−][src]
pub struct Verifier<'a> { /* fields omitted */ }Implementations
A type which verifies cryptographic signatures of data.
pub fn new<T>(
type_: MessageDigest,
pkey: &'a PKeyRef<T>
) -> Result<Verifier<'a>, ErrorStack> where
T: HasPublic,
pub fn new<T>(
type_: MessageDigest,
pkey: &'a PKeyRef<T>
) -> Result<Verifier<'a>, ErrorStack> where
T: HasPublic,
Creates a new Verifier.
This cannot be used with Ed25519 or Ed448 keys. Please refer to
new_without_digest.
OpenSSL documentation at EVP_DigestVerifyInit.
pub fn new_without_digest<T>(
pkey: &'a PKeyRef<T>
) -> Result<Verifier<'a>, ErrorStack> where
T: HasPublic,
pub fn new_without_digest<T>(
pkey: &'a PKeyRef<T>
) -> Result<Verifier<'a>, ErrorStack> where
T: HasPublic,
Creates a new Verifier without a digest.
This is the only way to create a Verifier for Ed25519 or Ed448 keys.
OpenSSL documentation at EVP_DigestVerifyInit.
Returns the RSA padding mode in use.
This is only useful for RSA keys.
This corresponds to EVP_PKEY_CTX_get_rsa_padding.
Sets the RSA padding mode.
This is only useful for RSA keys.
This corresponds to EVP_PKEY_CTX_set_rsa_padding.
Sets the RSA PSS salt length.
This is only useful for RSA keys.
This corresponds to EVP_PKEY_CTX_set_rsa_pss_saltlen.
Sets the RSA MGF1 algorithm.
This is only useful for RSA keys.
This corresponds to EVP_PKEY_CTX_set_rsa_mgf1_md.
Feeds more data into the Verifier.
Please note that PureEdDSA (Ed25519 and Ed448 keys) do not support streaming.
Use verify_oneshot instead.
OpenSSL documentation at EVP_DigestUpdate.
Determines if the data fed into the Verifier matches the provided signature.
OpenSSL documentation at EVP_DigestVerifyFinal.
Determines if the data given in buf matches the provided signature.
OpenSSL documentation at EVP_DigestVerify.